@@ -110,7 +110,7 @@ IconWindow::IconWindow ()
     set_default_size (300, 300);
 
     m_vbox.pack_start (m_iconlist);
-    m_vbox.pack_start (m_label, false, false);
+    m_vbox.pack_start (m_label, Gtk::PACK_SHRINK);
     add (m_vbox);
 
     m_label.drag_dest_set (target_table, Gtk::DEST_DEFAULT_ALL, Gdk::ACTION_COPY | Gdk::ACTION_MOVE);
